const withAnimations = require("animated-tailwindcss");

module.exports = withAnimations({
  purge: ["./pages/**/*.{js,ts,jsx,tsx}", "./components/**/*.{js,ts,jsx,tsx}"],
  darkMode: "media", // or 'media' or 'class'
  theme: {
    extend: {
      fontFamily: {
        nerd: ["DejaVuSansMono"],
      },
      colors: {
        "ada-werefox-cyan": {
          light: "#AAFFFF",
          DEFAULT: "#50FFFF",
          dark: "#008888",
        },
        "skye-werefox-blue": {
          light: "#94C2FF",
          DEFAULT: "#75B1FF",
          dark: "#0052B8",
          darker: "#00377A",
          darkest: "#00326B",
        },
        "skye-werefox-pink": {
          DEFAULT: "#FF84CA",
          dark: "#9E0054",
          darker: "#8A0040",
          darkest: "#75003F",
        },
        "skye-werefox-grey": {
          lightest: "#EEE",
          lighter: "#DBDBDB",
          light: "#CCC",
          DEFAULT: "#424242",
          dark: "#242424",
          darker: "#121212",
        },
        "alice-werefox-grey": {
          lightest: "#EEE",
          lighter: "#DBDBDB",
          light: "#CCC",
          DEFAULT: "#242424",
          dark: "#121212",
          darker: "#000",
        },
        "alice-werefox-red": {
          light: "#E08587",
          DEFAULT: "#c93439",
          dark: "#800008",
          darker: "#550006",
          darkest: "#7A0000",
        },
        "alice-werefox-blue": {
          light: "#9197F3",
          DEFAULT: "#1b29e0",
          dark: "#3300FF",
          darker: "#2C00DB",
          darkest: "#2700C2",
        },
      },
      flex: {
        5: "5 5 0%",
      },
      keyframes: {
        wiggle: {
          "0%, 100%": { transform: "rotate(-1deg)" },
          "50%": { transform: "rotate(1deg)" },
        },
        jiggle: {
          "0%, 100%": { transform: "rotate(0deg)" },
          "25%": { transform: "rotate(-10deg)" },
          "75%": { transform: "rotate(10deg)" },
        },
        yip: {
          "0%, 100%": { transform: "scale(1, 1)" },
          "50%": { transform: "scale(1.01, 1.01)" },
        },
        topslide1: {
          "0%": { "margin-top": "10em" },
          "2%": { "margin-top": "0em" },
          "8%": { "margin-top": "0em" },
          "10%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide2: {
          "0%": { "margin-top": "10em" },
          "10%": { "margin-top": "10em" },
          "12%": { "margin-top": "0em" },
          "18%": { "margin-top": "0em" },
          "20%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide3: {
          "0%": { "margin-top": "10em" },
          "20%": { "margin-top": "10em" },
          "22%": { "margin-top": "0em" },
          "28%": { "margin-top": "0em" },
          "30%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide4: {
          "0%": { "margin-top": "10em" },
          "30%": { "margin-top": "10em" },
          "32%": { "margin-top": "0em" },
          "38%": { "margin-top": "0em" },
          "40%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide5: {
          "0%": { "margin-top": "10em" },
          "40%": { "margin-top": "10em" },
          "42%": { "margin-top": "0em" },
          "48%": { "margin-top": "0em" },
          "50%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide6: {
          "0%": { "margin-top": "10em" },
          "50%": { "margin-top": "10em" },
          "52%": { "margin-top": "0em" },
          "58%": { "margin-top": "0em" },
          "60%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide7: {
          "0%": { "margin-top": "10em" },
          "60%": { "margin-top": "10em" },
          "62%": { "margin-top": "0em" },
          "68%": { "margin-top": "0em" },
          "70%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide8: {
          "0%": { "margin-top": "10em" },
          "70%": { "margin-top": "10em" },
          "72%": { "margin-top": "0em" },
          "78%": { "margin-top": "0em" },
          "80%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide9: {
          "0%": { "margin-top": "10em" },
          "80%": { "margin-top": "10em" },
          "82%": { "margin-top": "0em" },
          "88%": { "margin-top": "0em" },
          "90%": { "margin-top": "-10em" },
          "100%": { "margin-top": "-10em" },
        },
        topslide10: {
          "0%": { "margin-top": "10em" },
          "90%": { "margin-top": "10em" },
          "92%": { "margin-top": "0em" },
          "98%": { "margin-top": "0em" },
          "100%": { "margin-top": "-10em" },
        },
        scroll: {
          "0%": { transform: "translate(-40%, -40%)" },
          "50%": { transform: "translate(-20%, -20%)" },
          "100%": { transform: "translate(0%, 0%)" },
        },
      },
      animation: {
        wiggle: "wiggle 7s ease-in-out infinite",
        jiggle: "jiggle 5s cubic-bezier(0.75,0.25,0.25,0.75) infinite",
        yip: "yip 0.1s ease-in-out",
        topslide1: "topslide1 40s ease-in-out infinite",
        topslide2: "topslide2 40s ease-in-out infinite",
        topslide3: "topslide3 40s ease-in-out infinite",
        topslide4: "topslide4 40s ease-in-out infinite",
        topslide5: "topslide5 40s ease-in-out infinite",
        topslide6: "topslide6 40s ease-in-out infinite",
        topslide7: "topslide7 40s ease-in-out infinite",
        topslide8: "topslide8 40s ease-in-out infinite",
        topslide9: "topslide9 40s ease-in-out infinite",
        topslide10: "topslide10 40s ease-in-out infinite",
        scroll: "scroll 30s linear infinite",
      },
      width: {
        "2k": "3840px",
        "1080p": "1920px",
        "900p": "1600px",
        "720p": "1280px",
        "480p": "720px",
      },
      height: {
        "2k": "2160px",
        "1080p": "1080px",
        "900p": "900px",
        "720p": "720px",
        "480p": "480px",
      },
      maxWidth: {
        "1080p": "1920px",
        "900p": "1600px",
        "720p": "1280px",
        "480p": "720px",
      },
      maxHeight: {
        "1080p": "1080px",
        "900p": "900px",
        "720p": "720px",
        "480p": "480px",
      },
    },
  },
  variants: {
    extend: {
      brightness: ["hover", "dark"],
      ringColor: ["hover", "dark", "active", "group-hover"],
      animation: ["hover", "focus", "group-hover"],
    },
  },
  plugins: [],
});
